package com.ruoyi.project.check.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.check.mapper.TCheckLawsMapper;
import com.ruoyi.project.check.domain.TCheckLaws;
import com.ruoyi.project.check.service.ITCheckLawsService;

/**
 * 法规Service业务层处理
 *
 * @author ruoyi
 * @date 2022-11-28
 */
@Service
public class TCheckLawsServiceImpl implements ITCheckLawsService
{
    @Autowired
    private TCheckLawsMapper tCheckLawsMapper;

    /**
     * 查询法规
     *
     * @param id 法规主键
     * @return 法规
     */
    @Override
    public TCheckLaws selectTCheckLawsById(Long id)
    {
        return tCheckLawsMapper.selectTCheckLawsById(id);
    }

    /**
     * 查询法规列表
     *
     * @param tCheckLaws 法规
     * @return 法规
     */
    @Override
    public List<TCheckLaws> selectTCheckLawsList(TCheckLaws tCheckLaws)
    {
        return tCheckLawsMapper.selectTCheckLawsList(tCheckLaws);
    }

    /**
     * 新增法规
     *
     * @param tCheckLaws 法规
     * @return 结果
     */
    @Override
    public int insertTCheckLaws(TCheckLaws tCheckLaws)
    {
        return tCheckLawsMapper.insertTCheckLaws(tCheckLaws);
    }

    /**
     * 修改法规
     *
     * @param tCheckLaws 法规
     * @return 结果
     */
    @Override
    public int updateTCheckLaws(TCheckLaws tCheckLaws)
    {
        return tCheckLawsMapper.updateTCheckLaws(tCheckLaws);
    }
    @Override
    public int updateTCheckLawsStatus(TCheckLaws tCheckLaws)
    {
        return tCheckLawsMapper.updateTCheckLawsStatus(tCheckLaws);
    }

    /**
     * 批量删除法规
     *
     * @param ids 需要删除的法规主键
     * @return 结果
     */
    @Override
    public int deleteTCheckLawsByIds(Long[] ids)
    {
        return tCheckLawsMapper.deleteTCheckLawsByIds(ids);
    }

    /**
     * 删除法规信息
     *
     * @param id 法规主键
     * @return 结果
     */
    @Override
    public int deleteTCheckLawsById(Long id)
    {
        return tCheckLawsMapper.deleteTCheckLawsById(id);
    }
}
